function y = mest_bisquare_weight(x, sigma)
%MEST_BISQUARE_WEIGHT Weight function for the Tukey's bisquare M-estimator.
%
% y = mest_bisquare_weight(x, sigma)
%
% INPUT ARGUMENTS
%
%   x [matrix]: values where the weight function must be evaluated.
%
%   sigma: parameter of the Tukey's bisquare M-estimator.
%
% OUTPUT ARGUMENTS
%
%   y [matrix with size(x) = size(y)]: computed weights.
%
% 2011, Florent Brunet

% This file is part of MEST.
%
% MEST is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% MEST is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with MEST.  If not, see <http://www.gnu.org/licenses/>.

y = zeros(size(x));

ind = find(abs(x) <= sigma);
y(ind) = (1 - (x(ind)/sigma).^2).^2;
