function y = mest_cauchy_psi(x, gamma)
%MEST_CAUCHY_PSI Psi function for the Cauchy M-estimator.
%
% y = mest_cauchy_psi(x, gamma)
%
% INPUT ARGUMENTS
%
%   x [matrix]: values where the psi function must be evaluated.
%
%   gamma: parameter of the Cauchy M-estimator (scale of the Cauchy distribution).
%
% OUTPUT ARGUMENTS
%
%   y [matrix with size(x) = size(y)]: computed psi values.
%
% 2011, Florent Brunet

% This file is part of MEST.
%
% MEST is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% MEST is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with MEST.  If not, see <http://www.gnu.org/licenses/>.

y = 2.0 * x ./ (gamma^2 + x.^2);

