function y = mest_corrgauss_rho(x, alpha, w)
%MEST_CORRGAUSS_RHO Rho function for the corrupted Gaussian M-estimator.
%
% y = mest_corrgauss_rho(x, alpha, w)
%
% INPUT ARGUMENTS
%
%   x [matrix]: values where thertho function must be evaluated.
%
%   alpha, w: parameters of the corrupted Gaussian M-estimator.
%
% OUTPUT ARGUMENTS
%
%   y [matrix with size(x) = size(y)]: computed rho values.
%
% 2011, Florent Brunet

% This file is part of MEST.
%
% MEST is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% MEST is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with MEST.  If not, see <http://www.gnu.org/licenses/>.

y = -log(alpha * exp(-x.^2) + (1-alpha)*exp(-(x.^2) / (w^2))/w);
