function y = mest_huber_rho(x, sigma)
%MEST_HUBER_RHO Rho function for the Huber's M-estimator.
%
% y = mest_huber_rho(x, sigma)
%
% INPUT ARGUMENTS
%
%   x [matrix]: values where the tho function must be evaluated.
%
%   sigma: parameter of the Huber's M-estimator.
%
% OUTPUT ARGUMENTS
%
%   y [matrix with size(x) = size(y)]: computed rho values.
%
% 2011, Florent Brunet

% This file is part of MEST.
%
% MEST is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% MEST is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with MEST.  If not, see <http://www.gnu.org/licenses/>.

y = zeros(size(x));

ind = find(abs(x) <= sigma);
y(ind) = x(ind).^2 / 2;

ind = find(abs(x) > sigma);
y(ind) = sigma * (abs(x(ind)) - sigma/2);
